CREATE GRAIN fias VERSION '1.4';

-- *** TABLES ***
CREATE TABLE addrobj(
  /**Статус актуальности 0 – Не актуальный 1 - Актуальный*/
  actstatus INT,
  /**гуид АО
Не уникальный уид, для хранения истории изменения*/
  aoguid VARCHAR(36),
  /**Уникальный идентификатор записи. Ключевое поле.*/
  aoid VARCHAR(36) NOT NULL,
  /**Уровень АО
1 - регион
2 - зарезервирован
3 - район
4 - город
5 - внутригородская территория
6 - населенный пункт
7 - улицы
8 - зарезервирован
90 - дополнительная территория (ГСК, СНТ, лагери отдыха и т.п.)
91 - улицы на дополнительной территории (улицы, линии, проезды)*/
  aolevel INT,
  /**Код района*/
  areacode VARCHAR(3),
  /**Код автономии*/
  autocode VARCHAR(1),
  /**Статус центра (не нужен)*/
  centstatus INT,
  /**Код города*/
  citycode VARCHAR(3),
  /**Код АО*/
  code VARCHAR(17),
  /**Статус актуальности кладр4(не нужен)*/
  currstatus INT,
  /**Окончание действия записи*/
  enddate DATETIME,
  /**Формализованное наименование*/
  formalname VARCHAR(120),
  /**Формализованное наименование в нижнем регистре*/
  formalname_lowercase VARCHAR(120),
  /**Код ИФНС ФЛ (не нужен)*/
  ifnsfl VARCHAR(4),
  /**Код ИФНС ЮЛ (не нужен)*/
  ifnsul VARCHAR(4),
  /**Идентификатор записи  связывания с последующей исторической записью*/
  nextid VARCHAR(36),
  /**Официальное наименование*/
  offname VARCHAR(120),
  /**окато*/
  okato VARCHAR(11),
  /**октмо*/
  oktmo VARCHAR(11),
  /**Статус действия над записью таблица OperationStatus*/
  operstatus INT,
  /**Идентификатор родительского объекта (улица ссылается на город, город на район)*/
  parentguid VARCHAR(36),
  /**Код населенного пункта*/
  placecode VARCHAR(3),
  /**Код адресного объекта из КЛАДР 4.0 одной строкой без признака актуальности (последних двух цифр) (не нужен)*/
  plaincode VARCHAR(15),
  /**Почтовый индекс*/
  postalcode VARCHAR(6),
  /**Идентификатор записи связывания с предыдушей исторической записью*/
  previd VARCHAR(36),
  /**Код региона*/
  regioncode VARCHAR(2),
  /**Краткое наименование типа объекта*/
  shortname VARCHAR(10),
  /**Начало действия записи*/
  startdate DATETIME,
  /**Код улицы*/
  streetcode VARCHAR(4),
  /**Код территориального участка ИФНС ФЛ (не нужен)*/
  terrifnsfl VARCHAR(4),
  /**Код территориального участка ИФНС ЮЛ (не нужен)*/
  terrifnsul VARCHAR(4),
  /**Дата внесения (обновления) записи*/
  updatedate DATETIME,
  /**Код внутригородского района*/
  ctarcode VARCHAR(3),
  /**Код дополнительного адресообразующего элемента*/
  extrcode VARCHAR(4),
  /**Код подчиненного дополнительного адресообразующего элемента*/
  sextcode VARCHAR(3),
  /**Признак действующего адресного объекта*/
  livestatus INT,
  /**Внешний ключ на нормативный документ(не нужен)*/
  normdoc VARCHAR(36),
  CONSTRAINT pk_aoid PRIMARY KEY (aoid)
);

CREATE TABLE house(
  /**Guid записи родительского объекта (улицы, города, населенного пункта и т.п.)*/
  aoguid VARCHAR(36),
  /**Номер корпуса*/
  buildnum VARCHAR(10),
  /**Окончание действия записи*/
  enddate DATETIME,
  /**Признак владения*/
  eststatus INT,
  /**Глобальный уникальный идентификатор дома*/
  houseguid VARCHAR(36),
  /**Уникальный идентификатор записи дома*/
  houseid VARCHAR(36) NOT NULL,
  /**Номер дома*/
  housenum VARCHAR(20),
  /**Состояние дома*/
  statstatus INT,
  /**Код ИФНС ФЛ*/
  ifnsfl VARCHAR(4),
  /**Код ИФНС ЮЛ*/
  ifnsul VARCHAR(4),
  /**OKATO*/
  okato VARCHAR(11),
  /**OKTMO*/
  oktmo VARCHAR(11),
  /**Почтовый индекс*/
  postalcode VARCHAR(6),
  /**Начало действия записи*/
  startdate DATETIME,
  /**Номер строения*/
  strucnum VARCHAR(10),
  /**Признак строения*/
  strstatus INT,
  /**Код территориального участка ИФНС ФЛ*/
  terrifnsfl VARCHAR(4),
  /**Код территориального участка ИФНС ЮЛ*/
  terrifnsul VARCHAR(4),
  /**Дата время внесения записи*/
  updatedate DATETIME,
  /**Внешний ключ на нормативный документ*/
  normdoc VARCHAR(36),
  /**Счетчик записей домов для КЛАДР 4*/
  counter INT,
  CONSTRAINT pk_house PRIMARY KEY (houseid)
);

CREATE TABLE postcode(
  id VARCHAR(30) NOT NULL,
  aoid VARCHAR(36),
  aoguid VARCHAR(36),
  postcode VARCHAR(6),
  fulladdress VARCHAR(1000),
  CONSTRAINT pk_postcodeid PRIMARY KEY (id)
);

CREATE TABLE socrbase(
  level VARCHAR(5),
  socrname VARCHAR(50),
  scname VARCHAR(10),
  kod_t_st VARCHAR(4) NOT NULL,
  CONSTRAINT pk_kod_t_st PRIMARY KEY (kod_t_st)
);

-- *** FOREIGN KEYS ***
-- *** INDICES ***
CREATE INDEX idxparentguid ON addrobj(parentguid);
CREATE INDEX idxlevel ON addrobj(aolevel);
CREATE INDEX idxaoid ON addrobj(aoid);
CREATE INDEX idxaoguid ON addrobj(aoguid);
CREATE INDEX idxaopost ON addrobj(postalcode);
CREATE INDEX idxfnasaoid ON addrobj(formalname_lowercase, actstatus);
CREATE INDEX idx_house_aoguid ON house(aoguid);
CREATE INDEX idx_house_enddate ON house(enddate);
CREATE INDEX idx_house_housenum ON house(housenum);
CREATE INDEX idxpostcode ON postcode(postcode);
-- *** VIEWS ***
