# coding: utf-8
'''
Created on 18 февр. 2016 г.

@author: popov_v
'''

import json

from ru.curs.celesta.showcase.utils import XMLJSONConverter
from gridsettings._gridsettings_orm import grid_fieldCursor, user_grid_fieldCursor
from collections import OrderedDict
from java.text import SimpleDateFormat
from security.functions import userHasPermission

try:
    from ru.curs.showcase.core.jython import JythonDTO
except:
    from ru.curs.celesta.showcase import JythonDTO
    
def toolbar_button(context, sid, element_id):
    return {"item": {
                "@img":'gridToolBar/settings.png',
                "@hint":u'Настройка столбцов таблицы',
                "@visible": 'true' if userHasPermission(context, sid, "securityPerspective") else 'false',
                "action": {
                    "@show_in": "MODAL_WINDOW",
                    "#sorted": [
                        {"main_context": "current"},
                        {"modalwindow": {
                            "@caption": u"Настройки",
                            "@height": "650",
                            "@width": "800"}},
                        {"datapanel": {
                            "@type": "current",
                            "@tab": "current",
                            "element": {
                                "@id": 'gridSettingsCard',
                                "add_context": element_id}}}]}}}
    
    
def toolbar_button_default(context, sid, element_id):
    return {"item": {
                "@img":'gridToolBar/grid_default.png',
                "@hint": u'Сбросить настройки таблицы',
                "@visible": 'true' if userHasPermission(context, sid, "securityPerspective") else 'false',
                "action": {
                    "#sorted": [
                        {"main_context": 'current'},
                        {"server": {
                            "activity": {
                                "@id": "abandonTask",
                                "@name": "gridsettings.functions.gridSettings.restore_default.celesta",
                                "add_context": element_id}}},
                        {"datapanel": {
                            '@type':"current",
                            '@tab':"current",
                            'element': {
                                '@id':element_id}}}]}}}
    
def filter_button(element_id,height,width):
    return {"item": 
                {"@img":'gridToolBar/filter.ico',
                 '@text': u'Настроить фильтр',
                 "@hint":u'Настройки фильтра',
                 "@visible": 'false',
                 "action": {
                    "@show_in": "MODAL_WINDOW",
                    "#sorted": [
                        {"main_context": "current"},
                        {"modalwindow": {
                            "@caption": u"Настройки фильтра",
                            "@height": str(height),
                            "@width": str(width)}},
                        {"datapanel": {
                            "@type": "current",
                            "@tab": "current",
                            "element": {
                                "@id": element_id}}}]}}}    

    
def filter_reset_button(grid_element_id,filter_element_id):
    return {"item": 
                {"@img":'gridToolBar/reset.png',
                 '@text': u'Сбросить фильтр',
                 "@hint":u'Сбросить фильтр',
                 "@visible": 'false',
                 "action": {
                    "#sorted": [
                        {"main_context": 'current'},                                
                        {"server": {
                            "activity": {
                                "@id": "resetFilter",
                                "@name": "gridsettings.functions.gridSettings.filter_reset.celesta",
                                "add_context": filter_element_id}}},
                        {"datapanel": {
                            '@type':"current",
                            '@tab':"current",
                            'element': {
                                '@id':grid_element_id}}}]}}}

    
def toolbar_button_panel():
    return {'@id': 'gridSettingsCard',
            '@type': 'xforms',
            '@proc': 'gridsettings.functions.gridSettings.cardData.celesta',
            '@template': 'gridSettingsCard.xml',
            '@hideOnLoad': 'true',
            'proc': {
                '@id': 'save',
                '@name': 'gridsettings.functions.gridSettings.cardDataSave.celesta',
                '@type': 'SAVE'}}
    

def get_column_info(grid_field):
    field_prop = {"@id": grid_field.name}
    if grid_field.type == "boolean":
        field_prop["@type"] =  "IMAGE"
    if grid_field.type == "download":
        field_prop["@type"] =  "DOWNLOAD"
        field_prop["@linkId"] = grid_field.link_id
    if grid_field.width:
        field_prop["@width"] =  "%ipx" % grid_field.width
    return field_prop

    
def get_column_meta(context,grid_id,sid):
    user_grid_field = user_grid_fieldCursor(context)
    grid_field = grid_fieldCursor(context)
    
    columns = []
    grid_field.setRange('grid_id',grid_id)
    grid_field.orderBy('order')
    user_grid_field.setRange('grid_id',grid_id)
    user_grid_field.setRange('sid',sid)
    user_grid_field.orderBy('order')
    if user_grid_field.count() == 0:
        grid_field.setRange('is_default',True)
        for grid_field in grid_field.iterate():
            columns.append(get_column_info(grid_field))
    else:
        for user_grid_field in user_grid_field.iterate():
            grid_field.get(grid_id,user_grid_field.code)
            columns.append(get_column_info(grid_field))
    
    return columns

            
def get_column_header(grid_field,user_grid_field,grid_id,sid):    
    user_grid_field.setRange('sid',sid)
    user_grid_field.setRange('grid_id',grid_id)
    grid_field.setRange('grid_id',grid_id)
    if user_grid_field.count() == 0:
        grid_field.setRange('is_default',True)
        header = dict((grid_field.code,[grid_field.name,grid_field.code]) for grid_field in grid_field.iterate())
    else:
        header = dict()
        for user_grid_field in user_grid_field.iterate():
            grid_field.get(grid_id,user_grid_field.code)
            header[grid_field.code] = [grid_field.name, grid_field.code]
    
    return header

    
def set_column_value(header,row,table,grid_field,**kwargs):    
    if grid_field.code not in kwargs:
        if grid_field.type == 'download':
            value = u'Скачать'
        else:
            value = getattr(table,grid_field.code)
            if grid_field.type == "date":
                value = SimpleDateFormat("dd.MM.yyyy").format(value) if value else ""
            elif grid_field.type == "int":
                value = int(value) if value else ""
            elif grid_field.type == "boolean":
                value = "imagesingrid/%s.png" % ("yes" if value else "no")
            
        row[header[grid_field.code][2]] = value
    else:
        row[header[grid_field.code][2]] = kwargs[grid_field.code]

 
def get_column_data(header,grid_field,user_grid_field,grid_id,sid,table,row,**kwargs):
    grid_field.setRange('grid_id',grid_id)
    user_grid_field.setRange('grid_id',grid_id)
    user_grid_field.setRange('sid',sid)    
    if user_grid_field.count() == 0:
        grid_field.setRange('is_default',True)
        for grid_field in grid_field.iterate():
            set_column_value(header,row, table, grid_field, **kwargs) 
    else:
        for user_grid_field in user_grid_field.iterate():
            grid_field.get(grid_id,user_grid_field.code)
            set_column_value(header,row, table, grid_field, **kwargs)  
             
    
def cardData (context, main=None, add=None, filterinfo=None,
             session=None, elementId=None, sortColumnList=None, firstrecord=None, pagesize=None):
    session = json.loads(session)["sessioncontext"]
    sid = session['sid']
    grid_field = grid_fieldCursor(context)
    user_grid_field = user_grid_fieldCursor(context)
    
    used = OrderedDict()
    unused = []
    user_grid_field.setRange('sid',sid)
    user_grid_field.setRange('grid_id',add)
    grid_field.setRange('grid_id',add)
    grid_field.orderBy('order')
    user_grid_field.orderBy('order')
    if user_grid_field.count() == 0:
        grid_field.setRange('is_default',True)
        for grid_field in grid_field.iterate():
            used[grid_field.code] = {"code":grid_field.code,
                                     "name":grid_field.name}
        grid_field.setRange('is_default')
    else:
        for user_grid_field in user_grid_field.iterate():
            grid_field.get(add,user_grid_field.code)
            used[grid_field.code] = {"code":grid_field.code,
                                     "name":grid_field.name}    
    grid_field.orderBy('name')    

    _data = {"schema": 
                {"@xmlns":"",
                 "used": {
                    "field": [value for key,value in used.iteritems()]},
                    "unused": {
                        "field": [
                            {"code": grid_field.code,
                            "name": grid_field.name} for grid_field in grid_field.iterate() if grid_field.code not in used]}}}
    
    _settings = {"properties": 
                    {"event": 
                        {"@name":"single_click",
                         "@linkId": "1",
                         "action": {
                          ' #sorted' : [
                                {"main_context": "current"},
                                {"datapanel": {
                                        "@type": "current",
                                        "@tab": "current",
                                        "element": {
                                            "@id": add,
                                            "add_context": "current"}}}]}}}}

    return JythonDTO(XMLJSONConverter.jsonToXml(json.dumps(_data)),
                     XMLJSONConverter.jsonToXml(json.dumps(_settings)))
    

def cardDataSave(context, main=None, add=None, filterinfo=None, session=None, elementId=None, xformsdata=None):
    session = json.loads(session)
    sid = session['sessioncontext']['sid']
    
    user_grid_field = user_grid_fieldCursor(context)
    
    data = json.loads(xformsdata)["schema"]["used"]
    if not data:
        context.error("Выберите хотя бы одно поле")
    if not isinstance(data["field"], list):
        data["field"] = [data["field"]]
    
    user_grid_field.setRange('grid_id',add)
    user_grid_field.setRange('sid',sid)
    user_grid_field.deleteAll()
    user_grid_field.sid = sid
    user_grid_field.grid_id = add
    count = 1
    for field in data["field"]:
        user_grid_field.code = field['code']
        user_grid_field.order = count
        count += 1
        user_grid_field.insert()
        
        
def restore_default(context, main, add=None, filterinfo=None, session=None, elementId=None):
    user_grid_field = user_grid_fieldCursor(context)
    session = json.loads(session)['sessioncontext']
    sid = session['sid']
    user_grid_field.setRange('sid',sid)
    user_grid_field.setRange('grid_id',add)
    user_grid_field.deleteAll()
    
    
def filter_reset(context, main, add=None, filterinfo=None, session=None, elementId=None):
    context.getData().pop(add,'')
    