# coding: utf-8

import json

from common.sysfunctions import toHexForXml
from nci._nci_orm import status_listCursor
from ru.curs.celesta.showcase.utils import XMLJSONConverter
from umk._umk_orm import umk_versionCursor
from security.functions import userHasPermission


try:
    from ru.curs.showcase.core.jython import JythonDTO
except:
    from ru.curs.celesta.showcase import JythonDTO


def gridData(context, main, add=None, filterinfo=None, session=None, elementId=None,
             sortColumnList=None, firstrecord=None, pagesize=None):
    data = {
        'records': {
            'rec': []
        }
    }

    complex_program_id = json.loads(session)['sessioncontext']['related']['gridContext']['currentRecordId']
    umk_version = umk_versionCursor(context)
    status_list = status_listCursor(context)
    umk_version.setRange('complex_program_id', complex_program_id)
    umk_version.orderBy('number DESC')

    _header = {"uid": ["~~id"],
               "comment": [u"Комментарий"],
               "number": [u"Номер версии"],
               "name": [u"Статус"],

               "properties": ["properties"]}

    if sortColumnList:
        sortName = toHexForXml(sortColumnList[0].id)
        sortType = unicode(sortColumnList[0].sorting).lower()
    else:
        sortName = None

    for column in _header:
        _header[column].append(toHexForXml(_header[column][0]))
        if sortName == _header[column][1] and column != "name":
            umk_version.orderBy("%s %s" % (column, sortType))

    for umk_version in umk_version.iterate():
        row = {}
        row[_header["number"][1]] = umk_version.number
        row[_header["comment"][1]] = umk_version.comment
        status_list.get(umk_version.status_id)
        row[_header["name"][1]] = status_list.name
        row[_header["uid"][1]] = umk_version.uid

        row["properties"] = {
            "event": {
                "@name": "row_single_click",
                "action": {
                    '#sorted': [
                        {"main_context": "current"},
                        {"datapanel": {
                            "@type": "current",
                            "@tab": "current"
                        }}]
                }
            }
        }

        data['records']['rec'].append(row)

    return JythonDTO(XMLJSONConverter.jsonToXml(json.dumps(data)),
                     None)


def gridMeta(context, main=None, add=None, filterinfo=None, session=None,
             elementId=None, sortColumnList=None):
    complex_program_id = json.loads(session)['sessioncontext']['related']['gridContext']['currentRecordId']
    umk_version = umk_versionCursor(context)
    _header = {"uid": ["~~id"],
               "comment": [u"Комментарий"],
               "number": [u"Номер версии"],
               "name": [u"Статус"],

               "properties": ["properties"]}

    umk_version.setRange('complex_program_id', complex_program_id)

    totalCount = umk_version.count()
    meta = {
        "gridsettings": {
            "labels": {
                "header": u"Версии УМК"
            },
            "action": {
                "#sorted": [
                    {
                        "main_context": 'current'
                    },
                    {
                        "datapanel": {
                            "@type": 'current',
                            "@tab": 'current'
                        }
                    }
                ]
            },
            "columns": {
                "col": [
                    {
                        "@id": _header["number"][0],
                        "@width":'100px'
                    },
                    {
                        "@id": _header["name"][0],
                        "@width":'300px'
                    },
                    {
                        "@id": _header["comment"][0],
                        "@width":'300px'
                    }
                ]
            },
            "properties": {
                "@flip": "false",
                "@pagesize": 20,
                "@totalCount": totalCount,
                "@gridWidth": "100%",
                "@gridHeight": 150,
                "@rowHeight": 19,
                "@profile": "gr_withoutExcelSingleline.properties",
            }
        }
    }

    return JythonDTO(None,
                     XMLJSONConverter.jsonToXml(json.dumps(meta)))


def gridToolBar(context, main=None, add=None, filterinfo=None, session=None, elementId=None):

    umk_version = umk_versionCursor(context)
    sessionjson = json.loads(session)["sessioncontext"]

    addstyle = unicode(not userHasPermission(context, sessionjson["sid"], "addUmkVersion")).lower()
    editstyle = "true"
    delstyle = "true"
    change_status_style = "true"

    for gc in sessionjson["related"]['gridContext']:
        if gc['@id'] == 'umkVersionGrid' and 'currentRecordId' in gc:
            umk_version.get(gc['currentRecordId'])
            addstyle = unicode(not userHasPermission(context, sessionjson["sid"], "addUmkVersion")).lower()
            editstyle = unicode(not userHasPermission(context, sessionjson["sid"], "editUmkVersion")).lower()
            delstyle = unicode(not userHasPermission(context, sessionjson["sid"], "delUmkVersion") and
                               umk_version.status_id != 0).lower()
            change_status_style = unicode(not userHasPermission(context, sessionjson["sid"], "editUmkVersion")).lower()
            break

    data = {
        "gridtoolbar": {
            "#sorted": [
                {
                    "item": {
                        "@text": u"Добавить",
                        "@hint": u"Добавить версию",
                        "@disable": addstyle,
                        "action": {
                            "@show_in": "MODAL_WINDOW",
                            "#sorted": [
                                {
                                    "main_context": 'current'
                                },
                                {
                                    "modalwindow": {
                                        "@caption": u"Добавление",
                                        "@height": "300",
                                        "@width": "500"
                                    }
                                },
                                {
                                    "datapanel": {
                                        "@type": "current",
                                        "@tab": "current",
                                        "element": {
                                            "@id": "umkVersionCard",
                                            "add_context": ""
                                        }
                                    }
                                }
                            ]
                        }
                    }
                },
                {
                    "item": {
                        "@text": u"Изменить статус",
                        "@hint": u"Изменить статус",
                        "@disable": change_status_style,
                        "action": {
                            "@show_in": "MODAL_WINDOW",
                            "#sorted": [
                                {
                                    "main_context": 'current'
                                },
                                {
                                    "modalwindow": {
                                        "@caption": u"Изменение статуса",
                                        "@height": "300",
                                        "@width": "500"
                                    }
                                },
                                {
                                    "datapanel": {
                                        "@type": "current",
                                        "@tab": "current",
                                        "element": {
                                            "@id": "changeUmkVersionStatusCard",
                                            "add_context": ""
                                        }
                                    }
                                }
                            ]
                        }
                    }
                },
                {
                    "item": {
                        "@text": u"Удалить",
                        "@hint": u"Удалить",
                        "@disable": delstyle,
                        "action": {
                            "@show_in": "MODAL_WINDOW",
                            "#sorted": [
                                {
                                    "main_context": 'current'
                                },
                                {
                                    "modalwindow": {
                                        "@caption": u"Удаление",
                                        "@height": "150",
                                        "@width": "350"
                                    }
                                },
                                {
                                    "datapanel": {
                                        "@type": "current",
                                        "@tab": "current",
                                        "element": {
                                            "@id": "umkDeleteFromVersionGrid",
                                            "add_context": elementId
                                        }
                                    }
                                }
                            ]
                        }
                    }
                },
                {
                    "item": {
                        "@text": u"Перейти в режим работы с УМК",
                        "@hint": u"Перейти в режим работы с УМК",
                        "@disable": editstyle,
                        "action": {
                            "#sorted": [
                                {
                                    "main_context": "current"
                                },
                                {
                                    "navigator": {
                                        "@element": 'complexPrograms',
                                        "@refresh": "false"
                                    }
                                },
                                {
                                    "server": {
                                        "activity": {
                                            "@id": "selectVersion",
                                            "@name": "umk.grid.umkVersionGrid.selectVersion.celesta",
                                            "add_context": ""
                                        }

                                    }
                                }
                            ]
                        }
                    }
                }
            ]
        }
    }

    if "false" not in (addstyle, editstyle, delstyle, change_status_style):
        data = {
            "gridtoolbar": {
                "item": ""
            }
        }
    return XMLJSONConverter.jsonToXml(json.dumps(data))


def selectVersion(context, main=None, add=None, filterinfo=None, session=None):

    sessionjson = json.loads(session)['sessioncontext']
    context.getData()['toUmkFromUmkGrid'] = '1'
    for gc in sessionjson["related"]['gridContext']:
        if gc['@id'] == 'umkVersionGrid' and 'currentRecordId' in gc:
            context.getData()['umkVersionId'] = gc['currentRecordId']
